/*------------------------------------------------------------------------------
     Name: HttpIORCLient.java
  Project: jutils
  Version: $Revision: 1.4 $
    Datum: $Date: 2001/07/30 13:04:09 $
   Author: oliver.belikan@doubleslash.de
  Comment: Corba helper class to receive the ior
--------------------------------------------------------------------------------*/
package org.jutils.corba;

import java.util.*;
import java.net.*;
import java.io.*;

import org.jutils.log.LogManager;
import org.jutils.log.*;
import org.jutils.init.Property;
import org.jutils.runtime.StackTrace;

/**
 * Delivering the IOR over HTTP.
 * <p />
 * This little HTTP client is used to get the iorString on every
 * userrequest. As an example. http://localhost:port/service.ior<br />
 * Clients may access through this port the IOR if they
 * don't want to use a naming service. The default port ist 7109.
 */
public class HttpIORClient
{
   private String ME = "HttpIORCLient";   // this is the name of me
   protected static String LCN = null;    // Name of the logchannel

   /**
    * Create an new instance
    *
    * @param      ior
    *             The identifying object id.
    */
   public HttpIORClient () {
      // switch on logging to console
      LogChannel lc = new LogChannel(null);
      LogDeviceConsole ldc = new LogDeviceConsole(lc);
      lc.setLogLevel(LogChannel.LOG_ALL);
      lc.addLogDevice(ldc);
      LogManager.addLogChannel(ME, lc);
      this.LCN = ME;
   }

   /**
    * gets the ior from url like http://localhost:8989/name.ior
    * @param url like http://localhost8989/name.ior
    * @return the ior as string on null if no ior found
    */
   public String getIORFromUrl (String url) {

      Socket socket = null;

      try {

         String ip = url.substring (url.lastIndexOf("//")+2, url.lastIndexOf(":"));
         int port  = Integer.parseInt (url.substring(url.lastIndexOf(":")+1, url.lastIndexOf('/')));
         String service = url.substring (url.lastIndexOf('/')+1, url.length());

         /*
         LogManager.trace (LCN, ME, "ip=" + ip);
         LogManager.trace (LCN, ME, "port=" + port);
         LogManager.trace (LCN, ME, "service=" + service);
         */

         InetAddress addr = InetAddress.getByName(ip);
         socket = new Socket(addr, port);
         BufferedReader in =  new BufferedReader(new InputStreamReader(socket.getInputStream()));
         PrintWriter out = new PrintWriter(new BufferedWriter(new OutputStreamWriter(socket.getOutputStream())),true);

         // HTTP-Request absetzen und Antwort lesen
         // GET /service.ior HTTP/1.0\n
         out.println("GET /" + service + " HTTP/1.0\n");  // GET /service.ior HTTP/1.0\n
         String str;
         String read = "";
         while( (str=in.readLine()) != null )
            read += str;

         // Overhead der HTTP-Antwort entfernen
         // response is like this
         // Content-Type: ...
         // Content-Length:......
         // IOR: 89437984795874985............

         int iorOK = read.lastIndexOf("IOR:");
         if (iorOK != -1) {
            // received an valid IOR in response
            read = read.substring (iorOK).trim();  // extract IOR
            return read;
         }
         else {
            // no IOR is in response
           return null;
         }

      }
      catch (ConnectException c) {
         LogManager.error (LCN, ME, "HttpIORServer possible not running.");
         return null;
      }
      catch (Exception e) {
         LogManager.error (LCN, ME, StackTrace.getStackTrace(e));
         return null;
      }
      finally
      {
         try {
            if(socket != null)
            socket.close();
         }
         catch(Exception e) {
            System.out.println("Error! "+e.toString());
         }
      }
   }
}
