package org.jutils.runtime;

/**
 * Creation date: (16.10.2000 17:40:44)
 * @author: M.Winkler, doubleSlash NetBusiness GmbH
 */
public class PooledThread extends Thread {
    private ThreadPool pool_;
    private Runnable target_;
    private boolean shutDown_ = false;
    private boolean idle_ = false;



    /**
     * PooledThread constructor comment.
     */
    private PooledThread() {
        super();
    }



    /**
     * PooledThread constructor comment.
     * @param target java.lang.Runnable
     */
    private PooledThread(Runnable target) {
        super(target);
    }



    /**
     * PooledThread constructor comment.
     * @param target java.lang.Runnable
     * @param name java.lang.String
     */
    private PooledThread(Runnable target, String name) {
        super(target, name);
    }



    /**
     * Creates a new PooledThread by taking the passed parameters.
     * @param target java.lang.Runnable
     * @param name java.lang.String
     */
    public PooledThread(Runnable target, String name, ThreadPool pool) {
        super(name);
        pool_ = pool;
        target_ = target;
    }



    /**
     * PooledThread constructor comment.
     * @param name java.lang.String
     */
    private PooledThread(String name) {
        super(name);
    }



    /**
     * PooledThread constructor comment.
     * @param group java.lang.ThreadGroup
     * @param target java.lang.Runnable
     */
    private PooledThread(ThreadGroup group, Runnable target) {
        super(group, target);
    }



    /**
     * PooledThread constructor comment.
     * @param group java.lang.ThreadGroup
     * @param target java.lang.Runnable
     * @param name java.lang.String
     */
    private PooledThread(ThreadGroup group, Runnable target, String name) {
        super(group, target, name);
    }



    /**
     * PooledThread constructor comment.
     * @param group java.lang.ThreadGroup
     * @param name java.lang.String
     */
    private PooledThread(ThreadGroup group, String name) {
        super(group, name);
    }



    /**
     * @author: M.Winkler, doubleSlash NetBusiness GmbH
     *
     * @return java.lang.Runnable
     */
    public java.lang.Runnable getTarget() {
        return target_;
    }



    /**
     * Returnsx true if the thread is waiting for a new target.
     * @author: M.Winkler, doubleSlash NetBusiness GmbH
     *
     * @return boolean
     */
    public boolean isIdle() {
        return idle_;
    }



    /**
     * @author: M.Winkler, doubleSlash NetBusiness GmbH
     *
     */
    public void run() {
        while (!shutDown_) {
            idle_ = false;
            if (target_ != null) {
                target_.run();
            }
            idle_ = true;
            try {
                pool_.repool(this);
                synchronized (this) {
                    wait();
                }
            }
            catch (InterruptedException ie) {
            }
            idle_ = false;
        }
    }



    /**
     * Sets the next target of the task. This will be done
     * after the last target has done.
     * <strong>CAUTION!</strong>
     * This class is NOT multi target enabled! Only use ONE target!
     * @author: M.Winkler, doubleSlash NetBusiness GmbH
     *
     * @param newTarget java.lang.Runnable
     */
    public synchronized void setTarget(java.lang.Runnable newTarget) {
        target_ = newTarget;
        notifyAll();
    }



    /**
     * @author: M.Winkler, doubleSlash NetBusiness GmbH
     *
     */
    public synchronized void shutDown() {
        shutDown_ = true;
        notifyAll();
    }
}

